@@ -28,10 +28,10 @@
 #ifndef GPIOMONITOR_H
 #define GPIOMONITOR_H
 
-#include <QObject>
 #include <QDebug>
-#include <QSocketNotifier>
 #include <QFile>
+#include <QObject>
+#include <QSocketNotifier>
 
 #include "gpio.h"
 
@@ -48,7 +48,7 @@ public:
     bool isRunning() const;
     bool value() const;
 
-    Gpio* gpio();
+    Gpio *gpio();
 
 private:
     int m_gpioNumber;
@@ -56,13 +56,18 @@ private:
     QSocketNotifier *m_notifier;
     QFile m_valueFile;
     bool m_currentValue;
+#ifndef NYMEA_GPIO_USE_SYSFS
+    int m_eventFd = -1;
+#if defined(NYMEA_GPIO_LIBGPIOD_V2)
+    struct gpiod_edge_event_buffer *m_eventBuffer = nullptr;
+#endif
+#endif
 
 signals:
     void valueChanged(const bool &value);
 
 private slots:
     void readyReady(const int &ready);
-
 };
 
 #endif // GPIOMONITOR_H
